PyXMake Developer Guide: PyXMake.VTL.Command Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Public Attributes | List of all members
PyXMake.VTL.Command Class Reference

Parent class inherited from built-in exception. More...

Inheritance diagram for PyXMake.VTL.Command:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| cli (cls, *args, **kwargs)
| parse (cls, command, config, args)
| verify (cls, selection, **kwargs)
| run (cls, namespace=None, **kwargs)
| main (cls, **kwargs)

## Static Public Member Functions
| alias (*args, **kwargs)

## Public Attributes
str | CommandObjectKind = "PyXMake"
| String identifier of current instance.

## Detailed Description

Parent class inherited from built-in exception.

    Base class for all CLI commands

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.VTL.Command.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of Command class object.

Definition at line 54 of file __init__.py.

## Member Function Documentation

## ◆ alias()

PyXMake.VTL.Command.alias | ( | * | args,
|  | ** | kwargs )
| static

    Provides an aliases for a given script or command to be used in the CLI instead.

Definition at line 63 of file __init__.py.

## ◆ cli()

PyXMake.VTL.Command.cli | ( |  | cls,
|  | * | args,
|  | ** | kwargs )

    Get a tuple of all valid command line options.

    @note: Defaults to dropping all company (DLR) related prefixes from the scripts.

Definition at line 72 of file __init__.py.

## ◆ main()

PyXMake.VTL.Command.main | ( |  | cls,
|  | ** | kwargs )

    Main entrypoint of PyXMake CLI. All other subparsers are derived from here.

Definition at line 273 of file __init__.py.

## ◆ parse()

PyXMake.VTL.Command.parse | ( |  | cls,
|  |  | command,
|  |  | config,
|  |  | args )

    Parse user-supplied TOML file if given and add its arguments to a CLI command.

Definition at line 91 of file __init__.py.

## ◆ run()

PyXMake.VTL.Command.run | ( |  | cls,
|  |  | namespace = None,
|  | ** | kwargs )

    Execute command line parser for VTL module.

Definition at line 178 of file __init__.py.

## ◆ verify()

PyXMake.VTL.Command.verify | ( |  | cls,
|  |  | selection,
|  | ** | kwargs )

    Return command script if verified.

Definition at line 157 of file __init__.py.

## Member Data Documentation

## ◆ CommandObjectKind

str PyXMake.VTL.Command.CommandObjectKind = "PyXMake"

String identifier of current instance.

Definition at line 60 of file __init__.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/__init__.py